@@ -18,13 +18,11 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// ============================ //
-	// lang_admin.php - Dutch 1.1.3 //
-	// ============================ //
+	// ====================== //
+	// lang_admin.php - Dutch //
+	// ====================== //
 	//
 	// This languagefile was translated by Gerard Vandeninden gerard@brookstruefriends.nl
-	//
-	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
 
 	// general values
 	$lang['no'] = "nee";
@@ -34,7 +32,17 @@
 	$lang['desc'] = "Oplopend";
 	$lang['administrator'] = "administrator";
 	$lang['moderator'] = "moderator";
-	
+	$lang['gravatar_type_0'] = "Standard";
+	$lang['gravatar_type_1'] = "Mistery-Man";
+	$lang['gravatar_type_2'] = "Identicon";
+	$lang['gravatar_type_3'] = "Monsterid";
+	$lang['gravatar_type_4'] = "Wavatar";
+	$lang['gravatar_type_5'] = "Retro";
+	$lang['gravatar_position_left'] = "Links van het bericht";
+	$lang['gravatar_position_right'] = "Rechts van het bericht";
+	$lang['timestamp'] = "Tijdstempel";
+	$lang['quote'] = "Citeren uit";
+
 	// login.php
 	$lang['title'] = "MGB {MGB_VERSION} - Administratie";
 	$lang['login_username'] = "Usernaam:";
@@ -46,7 +54,7 @@
 	$lang['logged_in'] = "Je bent ingelogd als <b>{SESSION_USERNAME}</b>";
 	$lang['logged_out'] = "Vul gerbruikernaam en wachtwoord in.";
 	$lang['please_wait'] = "Je bent succesvol ingelogd.<br>Een  moment a.u.b....";
-	
+
 	// errormessages
 	$lang['errormessage1'] = "Vul alle velden in!";
 	$lang['errormessage2'] = "Deze usernaam/wachtwoord combinatie bestaat niet.";
@@ -63,6 +71,7 @@
 	$lang['errormessage13'] = "Er is al een nieuw wachtwoord aangevraagd voor dit account.<br>Het is niet mogelijk een nieuw wachtwoord aan te vragen totdat het vorige is bevestigd of verlopen.";
 	$lang['errormessage14'] = "De e-mail kon niet verzonden worden. Er is misschien een probleem met de mailserver.";
 	$lang['errormessage15'] = "Versienummer kan niet achterhaald worden omdat <a href=\"http://php.net/manual/en/function.fopen.php\">fopen()</a> is gedeactiveerd op je server.<br>Neem contact op met je host om dit probleem op te lossen.<br><br>Kijk voor de nieuwste versie op http://www.m-gb.org/.";
+	$lang['errormessage16'] = "Je nieuwe wachtwoord is te kort. veilige wachtwoorden zijn minstens ".$settings['password_min_length']." karakters lang.";
 
 	// general strings
 	$lang['back_to_mainpage'] = "Terug naar de hoofdpagina";
@@ -88,26 +97,26 @@
 	$lang['activate_entry'] = "Activeer dit bericht";
 	$lang['deactivate_entry'] = "Deactiveer dit bericht";
 	$lang['delete_entry'] = "Verwijder dit bericht";
-	$lang['mark_as_spam'] = "Mark as spam";
-	$lang['nospam_entry'] = "Mark entry as 'no spam' and activate it";
-	$lang['nospam_deactivate_entry'] = "Mark entry as 'no spam' but let it deactivated";
+	$lang['mark_as_spam'] = "Markeren als spam";
+	$lang['nospam_entry'] = "Markeren als 'geen spam' en activeren";
+	$lang['nospam_deactivate_entry'] = "Markeren als 'geen spam' MAAR niet activeren";
 	$lang['active'] = "Dit bericht is geactiveerd in het gastenboek";
 	$lang['inactive'] = "Dit bericht niet is geactiveerd in het gastenboek";
 	$lang['edit_entry'] = "Bewerk dit bericht";
-	$lang['do_nothing'] = "Do nothing ...";
-	$lang['delete_whole_spam'] = "Delete all spam entries";
-	$lang['mark_all_no_spam_deactivate'] = "Mark all entries as 'no spam' and activate it";
-	$lang['mark_all_no_spam_activate'] = "Mark all entries as 'no spam' but let them deactivated";
-	$lang['mark_all_as_spam'] = "Mark all entries as spam";
-	$lang['activate_all_entries'] = "Activate all entries";
-	$lang['deactivate_all_entries'] = "Deactivate all entries";
-	$lang['delete_all_entries'] = "Delete all entries";
+	$lang['do_nothing'] = "Doe niets ...";
+	$lang['delete_whole_spam'] = "Delete alle spam entries";
+	$lang['mark_all_no_spam_deactivate'] = "Markeer alle entries als 'geen spam' en activeer deze";
+	$lang['mark_all_no_spam_activate'] = "Markeer alle entries als 'geen spam' MAAR niet activeren";
+	$lang['mark_all_as_spam'] = "Markeer alle entries als spam";
+	$lang['activate_all_entries'] = "Activeer alle entries";
+	$lang['deactivate_all_entries'] = "Deactiveer alle entries";
+	$lang['delete_all_entries'] = "Delete alle entries";
 
 	$lang['sendmail_user_notification_title'] = "Je bericht op {DOMAIN} is geactiveerd";
 	$lang['sendmail_user_comment_title'] = "Aan je bericht op {DOMAIN} is een commentaar toegevoegd";
 	$lang['sendmail_adduser_title'] = "Je gebruiker gegevens op {DOMAIN}";
 	$lang['sendmail_adduser_text'] = "Je bent geregistreerd op {DOMAIN} door een administrator. Hier zijn je gegevens:<br /><br />Gebruikernaam: {ADDUSER_NAME}<br />Wachtwoord: {ADDUSER_PASSWORD}<br /><br />Je kan hier inloggen: {ADDUSER_URL}";
-	$lang['sendmail_admin_text'] = "{NAME} heeft een nieuw bericht in het gastenboek aangemaakt.<br /><br />Datum: {DATE}<br />Tijd: {TIME}<br /><br />---<br />{MESSAGE}<br />---";
+	$lang['sendmail_admin_text'] = "{NAME} heeft een nieuw bericht in het gastenboek aangemaakt.<br /><br />Datum: {DATE}<br />Tijd: {TIME}<br /><br />---<br />{MESSAGE}<br />---<br /><br />{URL_TO_GB}";
 	$lang['sendmail_user_text'] = "Hallo {NAME},<br /><br />Bedankt voor je bericht in ons gastenboek. Na beoordeling zal ik dit z.s.m. activeren.";
 	$lang['sendmail_user_notification_text'] = "Hallo {NAME},<br /><br />Je bericht op {DOMAIN} is nu geactiveerd. Je kan het hier bekijken: {URL_TO_GB}";
 	$lang['sendmail_comment_text'] = "Hallo {NAME},<br /><br />Aan jou bericht<br /><br />---<br />{MESSAGE}<br />---<br /><br />is net een commentaar toegevoegd. Je kan het hier bekijken: {URL_TO_GB}";
@@ -124,19 +133,22 @@
 	$lang['delete'] = "Berichten verwijderen";
 	$lang['edit'] = "Berichten bewerken";
 	$lang['spam'] = "Spam entries";
-	$lang['edit_smilies'] = "Edit smilies";
+	$lang['edit_smilies'] = "Bewerk smilies";
 	$lang['users'] = "Gebruiker administratie";
-	$lang['stats'] = "Statistics";
+	$lang['stats'] = "Statistieken";
 	$lang['license'] = "Licentie";
 	$lang['forum'] = "Forum";
 	$lang['bugreport'] = "Bug rappoteren";
 	$lang['version'] = "Versie";
 	$lang['manual'] = "Documentatie";
+	$lang['to_guestbook'] = "Naar het gastenboek";
 	$lang['paypal'] = "Als je MGB goed vindt, kan je een donatie aan het project geven om verdere ontwikkelingen te steunen.";
 
-	// settings.php
+	// settings.inc.php
 	$lang['edit_caption_general'] = "Algemene instellingen";
 	$lang['edit_caption_look'] = "Look &amp; feel";
+	$lang['edit_caption_bbcodes'] = "BBCodes";
+	$lang['edit_caption_smilies'] = "Emoticons";
 	$lang['edit_caption_gravatars'] = "Gravatar-support";
 	$lang['edit_caption_security'] = "Security";
 	$lang['edit_caption_email'] = "e-mail";
@@ -163,33 +175,50 @@
 	$lang['edit_language_path'] = "Taal:";
 	$lang['edit_badwords'] = "Badwords:";
 	$lang['edit_bbcode'] = "BBcodes:";
-	//$lang['edit_bbcode_original_img_width'] = "Gebruik de originele breedte van de afbeelding voor [img] BBCode:";
-	//$lang['edit_bbcode_img_width'] = "Alternatieve breedte voor afbeeldingen:";
+	$lang['edit_allow_img_tag'] = "IMG-Tag toestaan:";
+	$lang['edit_max_img_width'] = "Maximum Breedte van afbeelding:";
+	$lang['edit_max_img_height'] = "Maximum Hoogte van afbeelding:";
+	$lang['edit_center_img'] = "Centreer afbeeldingen:";
+	$lang['edit_allow_flash_tag'] = "FLASH-Tag toestaan:";
+	$lang['edit_max_flash_width'] = "Maximum Breedte van Flash:";
+	$lang['edit_max_flash_height'] = "Maximum Hoogte van Flash:";
+	$lang['edit_center_flash'] = "Centreer Flash:";
 	$lang['edit_smileys'] = "Smileys:";
+	$lang['edit_smileys_break'] = "Aantal smilies per regel:";
+	$lang['edit_smileys_order'] = "Volgorde van smilies:";
 	$lang['edit_captcha'] = "Captcha:";
 	$lang['edit_captcha_method'] = "Soort captcha:";
+	$lang['edit_captcha_coords'] = "Captcha co&ouml;rdinaten:";
+	$lang['edit_captcha_color'] = "Captcha tekstkleur:";
+	$lang['edit_captcha_angle'] = "Captcha hoek:";
 	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
 	$lang['edit_akismet_api'] = "Akismet API Key:";
-	$lang['edit_akismet_mark_as_spam'] = "Spam marking:";
-	$lang['edit_time_lock'] = "Sign lock:";
-	$lang['edit_time_lock_value'] = "Minimum time for sign lock:";
-	$lang['edit_time_lock_maxtime'] = "Maximum time for sign lock:";
+	$lang['edit_akismet_mark_as_spam'] = "Spam markering:";
+	$lang['edit_time_lock'] = "Wachttijd tot volgende bericht:";
+	$lang['edit_time_lock_value'] = "Minimum Wachttijd:";
+	$lang['edit_time_lock_maxtime'] = "Maximum Wachttijd:";
 	$lang['edit_user_notification'] = "Gebruiker bericht:";
 	$lang['edit_user_show_email'] = "Gebruiker mail in het gastenboek:";
 	$lang['edit_session_timeout'] = "Sessie timeout:";
+	$lang['edit_password_min_length'] = "Minimum lengte voor wachtwoorden:";
 	$lang['edit_moderated'] = "Gecontroleerd Gastenboek:";
 	$lang['edit_entries_per_page'] = "Berichten per pagina:";
 	$lang['edit_entries_order'] = "Volgorde van de berichten:";
+	$lang['edit_entries_order_asc_desc'] = "Sorteervolgorde:";
+	$lang['edit_entries_numbering'] = "Nummervolgorde:";
 	$lang['edit_spam_protection'] = "E-mail spam beveiliging:";
 	$lang['edit_ipblocker'] = "IP-Blocker:";
 	$lang['edit_wordwrap'] = "Wordwrap:";
 	$lang['edit_dateform'] = "Datum formaat:";
 	$lang['edit_gravatar_show'] = "activeer gravatars:";
 	$lang['edit_gravatar_rating'] = "Gravatar rating:";
+	$lang['edit_gravatar_type'] = "Niet geregistreerde gravatars:";
+	$lang['edit_gravatar_size'] = "Gravatar grootte:";
+	$lang['edit_gravatar_position'] = "Plaats:";
 
 	$lang['edit_expl_title'] = "Titel van het gastenboek.";
 	$lang['edit_expl_h_author'] = "Naam van de auteur van de webpagina.";
-	$lang['edit_expl_h_domain'] = "Top Level Domein (TLD) waar het gastenboek is geinstalleerd <b>zonder http://</b> aan het begin en <b>/</b> op het eind. (voorbeeld.net)";
+	$lang['edit_expl_h_domain'] = "Top Level Domein (TLD) waar het gastenboek is geinstalleerd <b>zonder http://</b> aan het begin en <b>/</b> op het eind. (www.voorbeeld.net)";
 	$lang['edit_expl_gb_path'] = "Het pad relatief aan hetTLD waar het gastenboek is geinstalleerd.";
 	$lang['edit_expl_h_keywords'] = "Keywords gescheiden door komma`s.";
 	$lang['edit_expl_h_description'] = "Een korte beschrijving van de pagina.";
@@ -206,34 +235,52 @@
 	$lang['edit_expl_template_path'] = "De template die gebruikt gaat worden.";
 	$lang['edit_expl_template_style_path'] = "De gewenste stijl van de template. Je kan dit niet selecteren totdat deze geladen is.";
 	$lang['edit_expl_iconset_path'] = "De gewenste grafic-set die de icons levert, smileys en captcha-achtergronden onafhankelijk van de template.";
-	$lang['edit_expl_language_path'] = "De taal die gebruikt wordt. Als je problemen hebt met umlauts en andere caracters zou het kunnen helpen om te converteren van uft-8 naar iso-8859-15 (latin9) of omgekeerd.";
+	$lang['edit_expl_language_path'] = "De taal die gebruikt wordt.<br><br><b>ATTENTIE:</b> Sinds versie <b>0.6.5</b> zijn talen die caracterset latin9 (iso-8859-15) gebruiken <b>NIET LANGER</b> ondersteund. Als je problemen hebt met missende variabelen, lege tekstvelden, enz, probeer over te schakelen naar een utf-8 taal en verwijder alle ''latin9''-talen uit de map ''language''.<br><br>Als je dan nog problemen hebt met umlauts of speciale caracters voer dan ''convert_ansi.php'' in de map 'install' uit.";
+	$lang['edit_expl_language_charset'] = "Tekenset:";
 	$lang['edit_expl_badwords'] = "Vul hier ongewenste woorden in gescheiden door comma`s, deze worden vervangen door sterren (*). Laat leeg om te deactiveren.";
 	$lang['edit_expl_bbcode'] = "Laat de gebruiker toe om tekst te bewerken.";
-	//$lang['edit_expl_bbcode_original_img_width'] = "Deactiveer deze optie als u alternatieve breedtes voor afbeeldingen wil gebruiken met de [img] BBCode.";
-	//$lang['edit_expl_bbcode_img_width'] = "Deze waarde bepaalt de maximum breedte voor afbeeldingen met de [img] BBCode.";
+	$lang['edit_expl_allow_img_tag'] = "De implementatie van afbeeldingen in een gastenboek bericht komt met enkele security risks. Beelden kunnen malware bevatten, of een beeld mag juridisch gezien niet gepubliceerd worden. Heel veel en grote afbeeldingen kunnen het laden van het gastenboek vertragen.<br><br><b>De IMG-Tag zou enkel in een gemodereerd gastenboek mogen geactiveerd worden.</b>";
+	$lang['edit_expl_max_img_width'] = "Definieerd de maximum breedte van een afbeelding.<br><br><b>ATTENTIE: Dit werkt enkel als <a href='http://de2.php.net/manual/en/function.getimagesize.php' target='_blank' title='php.net'>getimagesize();</a> werkt, of als de hoogte en breedte in de [img]-Tag zijn aangegeven zoals hier -> [img=width,height]address of image[/img]).</b>";
+	$lang['edit_expl_max_img_height'] = "Definieerd de maximum hoogte van een afbeelding.<br><br><b>ATTENTIE: Dit werkt enkel als <a href='http://de2.php.net/manual/en/function.getimagesize.php' target='_blank' title='php.net'>getimagesize();</a> werkt, of als de hoogte en breedte in de [img]-Tag zijn aangegeven zoals hier -> [img=width,height]address of image[/img]).</b>";
+	$lang['edit_expl_center_img'] = "Definieerd of [img]-Tag afbeeldingen gecentreerd worden weergegeven.";
+	$lang['edit_expl_allow_flash_tag'] = "Laat het invoegen van flash video toe, zoals van youtube.<br><br><b>Voor de veiligheid moet je dit enkel activeren als je een gecontroleerd gastenboek hebt.</b>";
+	$lang['edit_expl_max_flash_width'] = "Maximum breedte van een flashvideo.";
+	$lang['edit_expl_max_flash_height'] = "Maximum hoogte van een flashvideo.";
+	$lang['edit_expl_center_flash'] = "Plaatst een flashvideo in het midden.";
 	$lang['edit_expl_smileys'] = "Laat de gebruiker toe om smileys te gebruiken.";
+	$lang['edit_expl_smileys_break'] = "Maximaal aantal smilies per regel in ''newentry.php''. Kan nuttig zijn indien er veel smilies gebruikt worden.";
+	$lang['edit_expl_smileys_order'] = "Geeft aan hoe smilies gesorteerd zijn. Oplopend of Aflopend.";
 	$lang['edit_expl_captcha'] = "Indien geactiveerd moet er een catcha-code ingevuld worden om een bericht toe te voegen of een e-mail te verzenden.";
 	$lang['edit_expl_captcha_method'] = "Je kan kiezen tussen een veiligheidscode, of een rekensom die de gebruiker moet oplossen.";
-	$lang['edit_expl_akismet_plugin'] = "Akismet is een externe anti-spam-service, die nieuwe berichten controleert op spam. de akismet-plugin kan hier gedownload worden <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a>.<br><br><b>ATTENTION: With using the plugin 'akismet' you accept the transmission of data to a server in the United States of America. If you don't comply with that circumstance you MUST NOT USE 'Akismet'. Also your users have to agree with that if you activate the plugin.</b>";
+	$lang['edit_expl_captcha_coords'] = "Definieert de plaats waar de tekst begint in de achtergrond. Het begin is de <b>Linker onderkant van het eerste caracter</b>.";
+	$lang['edit_expl_captcha_color'] = "Definieert de tekstkleur van de captcha. De waarde moet in HTML-formaat zijn zonder de '#'.<br><br><b>Juist: <span class='newer_version'>505050</span><br>Fout: <span class='old_version'>#505050</span></b>";
+	$lang['edit_expl_captcha_angle'] = "Deze twee waarden definieren willekeurig de hoek waarmee de captcha wordt getekend.<br><br>The left value has to be <b>lower</b> than the right value.";
+	$lang['edit_expl_akismet_plugin'] = "Akismet is een externe anti-spam-service, die nieuwe berichten controleert op spam. de akismet-plugin kan hier gedownload worden <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a>.<br><br><b>ATTENTIE: Met het gebruik van de 'akismet'-plugin accepteer je het verzenden van data naar een server in de USA. Indien je hier niet mee accoord bent MAG JE 'Akismet' NIET GEBRUIKEN. Ook de Users moeten hiermee accoord gaan als je deze plugin activeerd.</b>";
 	$lang['edit_expl_akismet_api'] = "Om Akismet te kunnen gebruiken heb je een <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a> nodig. Meld je aan voor een gratis account en vul je key hier in.";
-	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet is geistalleerd!</span>";
-	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet is NIET geistalleerd!</span>";
-	$lang['edit_expl_akismet_mark_as_spam'] = "If this option is enabled, positive Akismet entries are marked as spam and appear in the administration panel so you can check them for yourself and decide what to do with.";
-	$lang['edit_expl_time_lock'] = "If this option is enabled, a counter that prevents sending the formular too fast runs in the background of a new entry. If the user is too fast with his entry, a message appears that tells him how many seconds he have to wait, until he can sign the guestbook.";
-	$lang['edit_expl_time_lock_value'] = "Minimum time a user has to wait to send the formular.";
-	$lang['edit_expl_time_lock_maxtime'] = "Maximum time a user has the chance to sign the guestbook. If it takes too long, the counter restarts.";
+	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version' style='font-size: 14px;'>Akismet is geistalleerd!</span>";
+	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version' style='font-size: 14px;'>Akismet is NIET geistalleerd!</span>";
+	$lang['edit_expl_akismet_mark_as_spam'] = "Indien deze optie is geactiveerd, worden positieve Akismet entries gemarkeerd als spam en verschijnen in het administratie panel hier kan je ze zelf controleren en bekijken wat je ermee doet.";
+	$lang['edit_expl_time_lock'] = "Indien deze optie is geselecteerd wordt er op de achtergrond en teller gestart die voorkomt dat het nieuwe bericht te snel wordt verstuurd. Indien de gebruiker te snel is met zijn bericht verschijnt er een bericht met de tijd die hij nog moet wachten totdat hij zijn bericht kan verzenden.";
+	$lang['edit_expl_time_lock_value'] = "Minimum wachttijdtijd tot het verzenden van het bericht.";
+	$lang['edit_expl_time_lock_maxtime'] = "Maximum tijd om een bericht aan te maken. Als het te lang duurt herstart de teller.";
 	$lang['edit_expl_user_notification'] = "Laat de gebruiker toe om te beslissen of hij een e-mail wil ontvangen wanneer zijn bericht wordt geactiveerd.";
 	$lang['edit_expl_user_show_email'] = "Laat de gebruiker toe om te beslissen of zijn e-mail adres getoond wordt in het gastenboek of niet. Indien hij de keuze uitschakeld kan alleen de admin hem een e-mail sturen.";
-	$lang['edit_expl_session_timeout'] = "Een inactieve gebruiker wordt automatisch uitgelogd indien de tijd is verstreken. Uiygedrukt in <b>seconden</b>. Waarde moet >= <b>60</b>.";
+	$lang['edit_expl_session_timeout'] = "Een inactieve gebruiker wordt automatisch uitgelogd indien de tijd is verstreken. Uitgedrukt in <b>seconden</b>. Waarde moet >= <b>60</b>.";
+	$lang['edit_expl_password_min_length'] = "Definieert de minimum lengte van wachtwoorden van Administrators / Moderators.";
 	$lang['edit_expl_moderated'] = "Indien geactiveerd moeten posts eerst geactiveerd worden door de admin.";
 	$lang['edit_expl_entries_per_page'] = "Aantal posts per pagina. De waarde <b>mag niet 0 zijn</b>.";
 	$lang['edit_expl_entries_order'] = "Defineerd de volgorde waarin posts genummerd worden";
+	$lang['edit_expl_entries_order_asc_desc'] = "Sorteervolgorde van berichten.";
+	$lang['edit_expl_entries_numbering'] = "Nummering van berichten.<br><br><b>Attentie:</b> Dit heeft niets te maken met de sorteervolgorde.";
 	$lang['edit_expl_spam_protection'] = "Wanneer geactiveerd krijgt de gebruiker een contact-form, als hij op het eMail-symbool in een  post klikt. Op deze manier zullen e-mail adressen <b>niet</b> getoond worden.";
 	$lang['edit_expl_ipblocker'] = "Voorkomt meerder posts van 1 gebruiker in rij.";
 	$lang['edit_expl_wordwrap'] = "Geeft het aantal caracters aan voordat een heel lang woord wordt afgebroken. <b>0</b> om te deactiveren.";
 	$lang['edit_expl_dateform'] = "De manier waarop de datum getoond wordt. Aanpassen is mogelijk met de PHP-functie <a class='admin' href='http://www.php.net/manual/en/function.date.php' title='date()' target='_blank'>date()</a>.";
 	$lang['edit_expl_gravatar_show'] = "Gravatars (Global Recognized Avatars) zijn kleine afbeeldingen die naast de post van de gebruiker getoond worden. Zij hangen af van, als de gebruiker een <a class=\"admin\" href=\"http://site.gravatar.com/\" target=\"_blank\" title=\"Gravatar Service\">registred</a> is zijn e-mail adres bij deze service.";
-	$lang['edit_expl_gravatar_rating'] = "definieerd tot welke rating gravatars getoond worden.<br><br><b>G</b> = voor elke leeftijd<br><b>PG</b> = light violence illustration, provocative dressed people and gestures<br><b>R</b> = intensive violence illustration, obscenity<br><b>X</b> = explicit sexual pictures";
+	$lang['edit_expl_gravatar_rating'] = "Definieerd tot welke rating gravatars getoond worden.<br><br><b>G</b> = voor elke leeftijd<br><b>PG</b> = light violence illustration, provocative dressed people and gestures<br><b>R</b> = intensive violence illustration, obscenity<br><b>X</b> = explicit sexual pictures";
+	$lang['edit_expl_gravatar_type'] = "Hier geef je aan hoe een gravatar wordt weergegeven indien het email adres van de gebruikers niet geregistreerd is bij de service.";
+	$lang['edit_expl_gravatar_size'] = "Grootte van de gravatar in <b>pixels</b>.";
+	$lang['edit_expl_gravatar_position'] = "Plaatst de gravatar links of rechts van het bericht.";
 
 	// edit.php
 	$lang['ID'] = "ID:";
@@ -253,16 +300,16 @@
 	$lang['comment'] = "Commentaar:";
 
 	// smilies.inc.php
-	$lang['add_smilies_descr'] = "Here you can edit or remove smilies.<br><br>All smilies have to be in the folder <b>'images/smilies/'</b> in the root directory of the guestbook. You only have to put the filename into the <b>empty textbox</b> and then press <b>save</b>.<br><br><b>Please notice: If you change existing smilies or place holders that were already used in entries, then they cannot be correctly replaced any more! You have to edit these entries by hand.</b>";
-	$lang['smiley_path'] = "Filename";
-	$lang['smiley_replacement'] = "Place holder";
-	$lang['add_new_smiley'] = "Add smiley";
-	$lang['delete_checked_smilies'] = "... remove from list, keep unchecked";
-	$lang['keep_checked_smilies'] = "... keep, remove unchecked";
-	$lang['smiley_width'] = "Width";
-	$lang['smiley_height'] = "Height";
+	$lang['add_smilies_descr'] = "Hier kan je smilies bewerken of verwijderen.<br><br>Alle smilies moeten in de map <b>'images/smilies/'</b> staan in de root directory van het gastenboek. Vul de naam van het bestand in de <b>lege tekstbox onder bestandsnaam</b>, de vervangende tekst en de afmetingen, en druk op <b>Opslaan</b>.<br><br>Je kan meer dan 1 vervangende tekst opgeven per smilie. Gescheiden door een <b>comma en een spatie</b>. De <b>eerste</b> caractercombinatie zal gebruikt worden om de smilie in de tekst in te voegen in ''newentry.php''.<br><br><span class='same_version'>Juist:</span> :smile:, :), :-)<br><span class='old_version'>Fout:</span> :smile:,:),:-)<br><br><b>Let op: Indien je bestaande smilies veranderd, die al gebruikt zijn in berichten, kunnen deze niet correct meer worden weergegeven! Je zal deze berichten handmatig moeten aanpassen.</b>";
+	$lang['smiley_path'] = "Bestandsnaam";
+	$lang['smiley_replacement'] = "Vervangende tekst";
+	$lang['add_new_smiley'] = "Smiley toevoegen";
+	$lang['delete_checked_smilies'] = "... verwijder uit lijst, behoud niet aangevinkt";
+	$lang['keep_checked_smilies'] = "... behoud, verwijder niet aangevinkt";
+	$lang['smiley_width'] = "Breedte";
+	$lang['smiley_height'] = "Hoogte";
 	$lang['smilies'] = "Smilies";
-	$lang['checked_smilies'] = "Checked smilies ...";
+	$lang['checked_smilies'] = "Aangevinkte smilies ...";
 
 	// edit_user.inc.php
 	$lang['user_is_active'] = "Gebruiker is actief:";
@@ -273,7 +320,7 @@
 	$lang['r_delete'] = "Berichten verwijderen:";
 	$lang['r_edit'] = "Berichten aanpassen:";
 	$lang['r_spam'] = "Manage spam:";
-	$lang['r_edit_smilies'] = "Edit smilies";
+	$lang['r_edit_smilies'] = "Bewerk smilies";
 	$lang['old_password'] = "Uw huidige wachtwoord:";
 	$lang['new_password_1'] = "Nieuw wachtwoord:";
 	$lang['new_password_2'] = "Bevestig nieuw wachtwoord:";
@@ -294,11 +341,13 @@
 	$lang['old_version'] = "Uw versie is te oud.<br>Een update wordt aanbevolen.<br><br><a href='http://www.m-gb.org/index.php?id=download_gb' class='admin' target='_blank' title='Update now'>To the new version</a>";
 	$lang['same_version'] = "U gebruikt de nieuwste versie.<br>Een update is niet nodig.";
 	$lang['newer_version'] = "Uw versie is nieuwer dan de nieuwste stabiele versie.<br>Een update is niet nodig.";
-	$lang['new_version_available'] = "A new version is available: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Upgrade now!'>{LATEST_VERSION}</a>";
+	$lang['new_version_available'] = "Een nieuwe versie is beschikbaar: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Upgrade now!'>{LATEST_VERSION}</a>";
 
 	// lostpassword.php
 	$lang['lostpassword_mail'] = "Uw e-mail adres:";
 	$lang['get_new_pw'] = "Aanvraag nieuw wachtwoord";
 	$lang['lostpassword_success'] = "De aanvraag wordt verwerkt. Zodadelijk ontvangt u een e-mail<br>met een bevestigings-link. Klik hierop om uw nieuw wachtwoord te bevestigen.";
+	$lang['lostpassword_no_success'] = "Jou verzoek kan niet afgehandeld worden, er is een probleem met de mailserver.";
 	$lang['lostpassword_success_created'] = "Uw nieuwe login details zijn<br>naar u gestuurd per e-mail.";
+	$lang['lostpassword_no_success_created'] = "Jou verzoek kan niet afgehandeld worden, er is een probleem met de mailserver.";
 ?>
