@@ -19,9 +19,9 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 	
-	// =============================== //
-	// lang_settings.php - Dutch 1.1.2 //
-	// =============================== //
+	// ========================= //
+	// lang_settings.php - Dutch //
+	// ========================= //
 	//
 	// This languagefile was translated by Gerard Vandeninden gerard@brookstruefriends.nl  
 	//
@@ -31,5 +31,6 @@
 	$charset = "utf-8";
 	$language = "Dutch / Nederlands";
 	$language_short = "nl";
-	$language_version = "1.1.2";
+	$language_version = "1.3";
+	$language_author = "Gerard Vandeninden";
 ?>
