@@ -18,38 +18,39 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// ============================== //
-	// lang_install.php - English 1.4 //
-	// ============================== //
+	// ========================== //
+	// lang_install.php - English //
+	// ========================== //
 	//
 	// This languagefile was translated by Christian Rech alias HeyJ (mail@heyj.de)
 	// and edited by Jürgen Schäfer ==> juergen.schaefer(at)minetoshsoft.com
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
 
-// header
+	// header
 	$lang['h_title'] = "Welcome to the installation of MGB {MGB_VERSION}";
 
-// general
+	// general
 	$lang['next_step'] = "&raquo; Next &raquo;";
+	$lang['cancel'] = "Cancel";
 	$lang['yes'] = "Yes";
 	$lang['no'] = "No";
 	$lang['active'] = "Active";
 	$lang['inactive'] = "Inactive";
 
-// installation
+	// installation
 	$lang['title'] = "Installation of MGB {MGB_VERSION}";
 
 	$lang['eula_expl'] = "The MGB OpenSource guest book is distributed under the GNU/GPL license for free software (GPLv2). If you want to use the guest book, regardless of purpose, you have to agree to this license. Please read it carefully.";	
 	$lang['eula_agree'] = "I agree with the conditions of the GNU/GPL.";
 	$lang['eula_disagree'] = "I do <strong>not</strong> agree with the conditions of the GNU/GPL.";
+
 	$lang['thanks'] = "Thank you for agreeing with the GNU/GPL and that you choose the MGB OpenSource guest book.";
 	$lang['expl_step1'] = "Here are shown some important information, necessary for the installation. You can see by the icons if you can install MGB on your server.";
 	$lang['expl_step2'] = "Please provide the login data for your database and for the administrator account, which has to be created.";
+	$lang['expl_step3'] = "Congratulations! The MGB ".MGB_VERSION." has been successfully installed on your server. Please delete the folder ''install'' for your own security. Alternatively, you can just rename it.<br><br>You can now go to the administration. We recommend changing the username if you chose the standard name ''admin''.<br><br>Have a lot of fun with your new guest book!";
+	$lang['expl_step3_fail'] = "An error occurred. Please restart the installation from the beginning and check your connection data again.<br><br>If installation fails again, you can find help here:<br><a href='http://forum.m-gb.org/' target='_blank'>Forum of MGB OpenSource Guestbook</a>";
 
-	$lang['expl_step3'] = "Congratulations! The MGB {MGB_VERSION} has been successfully installed on your server. Please delete the folder ''install'' for your own security. Alternatively, you can just rename it.<br><br>You can now go to the administration. We recommend changing the username if you choose the standard name ''admin''.<br><br>Have a lot of fun with your new guest book!";
-	$lang['expl_step3_2'] = "An error occurred. Please restart the installation from the beginning and check your connection data again.";
-
-// step 1
+	// step 1
 	$lang['srvcfg_server'] = "Server:";
 	$lang['srvcfg_phpversion'] = "PHP Version:";
 	$lang['srvcfg_mysqlversion'] = "MySQL Version:";
@@ -57,7 +58,7 @@
 	$lang['srvcfg_writable'] = "Config. writeable:";
 	$lang['srvcfg_reg_globals'] = "register_globals:";
 
-// errormessages step 1
+	// errormessages step 1
 	$lang['error_1'] = "Your PHP version is outdated. MGB demands a newer version. We recommend an update.";
 	$lang['error_2'] = "Your MySQL version is outdated. MGB demands a newer version. We recommend an update.";
 	$lang['error_3'] = "The GD library is not available. The guest book will work, but without security code.";
@@ -65,7 +66,7 @@
 	$lang['error_5'] = "register_globals is activated. This implies a security risk. It should be deactivated.";
 	$lang['no_error'] = "All values are OK! Please click on ''Next''";
 
-// step 2
+	// step 2
 	$lang['db_title'] = "Database information:";
 	$lang['db_hostname'] = "Host:";
 	$lang['db_dbname'] = "Database name:";
@@ -83,12 +84,15 @@
 	$lang['post_admin_name'] = "Webmaster";
 	$lang['post_admin_username'] = "Admin";
 
-// errormessages step 2
+	// errormessages step 2
 	$lang['error_1_step2'] = "Please fill in all fields!";
 	$lang['error_2_step2'] = "At least one of the two email addresses is invalid.";
 	$lang['error_3_step2'] = "The connection to the database could not be established. Please check the database information.";
 	$lang['error_4_step2'] = "The database already contains a previous installation using this prefix. Please choose another prefix.";
+	$lang['error_5_step2'] = "The prefix you have chosen contains special characters which are not allowed. Please try another prefix. Allowed characters: - and _";
 
 	$lang['to_administration'] = "To the administration";
-	$lang['to_guestbook'] = "To the guest book";
+	$lang['import'] = "Import entries from an older version (0.5.x or older ONLY)";
+	$lang['to_guestbook'] = "To the guestbook";
+	$lang['to_install'] = "Try again";
 ?>
