@@ -19,12 +19,12 @@
 	*/
 
 	// ==================================== //
-	// lang_main.php - Schweizerdeutsch 1.2 //
+	// lang_main.php - Schweizerdeutsch 1.4 //
 	// ==================================== //
 	//
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
 
-	// strings of index.php
+	// INDEX.PHP
 	$lang['install_directory_exists'] = "De Ordner 'install' isch nonig gl&ouml;scht worde !!.<br>Da das es Sicherheitsrisiko isch, sett de gl&ouml;scht werde !<br>Vergiss aber n&ouml;d nacheme Update zerscht <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> uszf&uuml;ere!";
 	$lang['new_entry'] = "Itrag schribe";
 	$lang['new_entry_descr'] = "Da chamer en eigene neue Itrag schribe";
@@ -53,8 +53,9 @@
 	$lang['email_no'] = "{ENTRY_NAME} will kei eMails &uuml;bers G&auml;schtebuech.";
 	$lang['hp_of'] = "Internetsite vo {ENTRY_NAME}";
 	$lang['gravatar'] = "Gravatar von {ENTRY_NAME}";
+	$lang['quote'] = "Zitat von";
 
-	// strings of newentry.php
+	// NEWENTRY.PHP
 	$lang['name'] = "Din Name:";
 	$lang['city'] = "Dis Wohnort:";
 	$lang['email'] = "Dis eMail:";
@@ -69,17 +70,6 @@
 	$lang['user_accept_akismet_service'] = "Dieser Eintrag wird durch 'Akismet' auf Spam überprüft. Ich bin mir bewusst, dass wenn ich den Eintrag absende, persönliche Daten von mir auf einen Server in die USA geschickt werden, und akzeptiere dies.";
 	$lang['send'] = "Itrag schribe";
 	$lang['preview'] = "Vorschau";
-	$lang['errormessage1'] = "Aso ohni en Itrag-Text bringt das n&uuml;t!";
-	$lang['errormessage2'] = "Es mues e g&uuml;ltigi eMail-Adr&auml;sse ig&auml; werde!";
-	$lang['errormessage3'] = "Es mues en Name ig&auml; werde!";
-	$lang['errormessage4'] = "Das isch kei g&uuml;ltigi<br>eMail Adr&auml;sse!";
-	$lang['errormessage5'] = "ist keine g&uuml;ltige<br>ICQ Nummer!";
-	$lang['errormessage6'] = "D'IP-Sperre verb&uuml;tet en neue Itrag!";
-	$lang['errormessage7'] = "De Sicherheitscode isch falsch oder n&ouml;d ig&auml;&auml; worde!";
-	$lang['errormessage8'] = "D&auml; M&auml;nsch will kei eMail empfange!";
-	$lang['errormessage9'] = "Es isch en Fehler bim eMail-Versand uftr&auml;te!";
-	$lang['errormessage10'] = "Spamschutz: Das Formular wurde zu schnell abgesendet. Bitte warte noch {TIME_LOCK_REST} Sekunden.";
-	$lang['errormessage11'] = "Die Akismet-Einverständniserklärung wurde nicht akzeptiert.<br>Um den Eintrag übernehmen zu können, muss sie akzeptiert werden.";
 	$lang['security_code'] = "Sicherheitscode";
 	$lang['captcha_what_is_that'] = "Was isch das?";
 	$lang['captcha_wikipedia'] = "http://de.wikipedia.org/wiki/Captcha";
@@ -89,23 +79,8 @@
 	$lang['entry_success_mod'] = "De Itrag isch gschpeichered worde, de Admin wird en beguetachte und den w&auml;ner ok isch freischalte.";
 	$lang['entry_success'] = "De Itrag isch gschpeichered und isch jetz Online.";
 	$lang['forwarding'] = "Si werdet i 5 Sekunde automatisch witergeleitet. W&auml;nn n&ouml;d, den klicked Si bitte uf ''Zrugg zu de Haubtsite''.";
-	$lang['bbcodes'] = "BBCodes:";
-	$lang['bbcode_help_bold'] = "Fett";
-	$lang['bbcode_help_italic'] = "Kursiv";
-	$lang['bbcode_help_url'] = "Link";
-	$lang['bbcode_textsize'] = "Schriftgr&ouml;ssi";
-	$lang['bbcode_extrasmall'] = "Winzig";
-	$lang['bbcode_small'] = "Chli";
-	$lang['bbcode_default'] = "Standard";
-	$lang['bbcode_big'] = "Gross;";
-	$lang['bbcode_extrabig'] = "Riesig";
-	$lang['bbcode_textcolor'] = "Schriftfarb";
-	$lang['bbcode_help_size'] = "Schriftgr&ouml;ssi";
-	$lang['smileys'] = "Smilies:";
-	$lang['sendmail_admin_title'] = "Neue G&auml;stebuechitrag vo '{NAME}'";
-	$lang['sendmail_user_title'] = "Ihre Itrag auf {DOMAIN}";
 
-	// strings of email.php
+	// EMAIL.PHP
 	$lang['email_name'] = "Ihre Name:";
 	$lang['email_email'] = "Ihres eMail:";
 	$lang['email_message'] = "Ihri Nachricht:";
@@ -118,4 +93,44 @@
 	$lang['email_sendcopytome'] = "Ich m&ouml;chti e Kopie vo dem eMail &uuml;bercho.";
 	$lang['email_success'] = "Ihri eMail isch erfolgrich a de Benutzer verschickt worde.";
 	$lang['email_fail'] = "Die eMail h&auml;t n&ouml;d verschickt werde ch&ouml;ne. M&ouml;glicherwis git's es Problem mit em Mailserver.";
+
+	// ERRORMESSAGES
+	$lang['errormessage1'] = "Aso ohni en Itrag-Text bringt das n&uuml;t!";
+	$lang['errormessage2'] = "Es mues e g&uuml;ltigi eMail-Adr&auml;sse ig&auml; werde!";
+	$lang['errormessage3'] = "Es mues en Name ig&auml; werde!";
+	$lang['errormessage4'] = "Das isch kei g&uuml;ltigi<br>eMail Adr&auml;sse!";
+	$lang['errormessage5'] = "ist keine g&uuml;ltige<br>ICQ Nummer!";
+	$lang['errormessage6'] = "D'IP-Sperre verb&uuml;tet en neue Itrag!";
+	$lang['errormessage7'] = "De Sicherheitscode isch falsch oder n&ouml;d ig&auml;&auml; worde!";
+	$lang['errormessage8'] = "D&auml; M&auml;nsch will kei eMail empfange!";
+	$lang['errormessage9'] = "Es isch en Fehler bim eMail-Versand uftr&auml;te!";
+	$lang['errormessage10'] = "Spamschutz: Das Formular wurde zu schnell abgesendet. Bitte warte noch {TIME_LOCK_REST} Sekunden.";
+	$lang['errormessage11'] = "Die Akismet-Einverständniserklärung wurde nicht akzeptiert.<br>Um den Eintrag übernehmen zu können, muss sie akzeptiert werden.";
+
+	// BBCODES
+	$lang['bbcodes'] = "BBCodes:";
+	$lang['bbcode_bold'] = "Fett";
+	$lang['bbcode_help_bold'] = "Fette Darstellung des Textes";
+	$lang['bbcode_italic'] = "Kursiv";
+	$lang['bbcode_help_italic'] = "Kursive Darstellung des Textes";
+	$lang['bbcode_url'] = "URL";
+	$lang['bbcode_help_url'] = "F&uuml;gt einen Hyperlink ein. M&ouml;glich sind: [url]http://www.test.ch/[/url] oder [url=http://www.test.ch/]Test[/url] oder [url=http://www.test.ch/][img]Adresse zum Bild[/img][/url]";
+	$lang['bbcode_img'] = "Grafik";
+	$lang['bbcode_help_img'] = "F&uuml;gt ein Bild ein. M&ouml;glich sind: [img]Adresse zum Bild[/img] oder [img=Breite,H&ouml;he]Adresse zum Bild[/img]";
+	$lang['bbcode_flash'] = "Flash";
+	$lang['bbcode_help_flash'] = "F&uuml;gt ein Flashvideo ein. -> [flash=Breite,H&ouml;he]URL[/flash]";
+	$lang['bbcode_quote'] = "Zitat";
+	$lang['bbcode_help_quote'] = "F&uuml;gt ein Zitat ein. M&ouml;glich sind: [quote]Zitat[/quote] oder [quote=Name des Zitierten]Zitat[/quote]";
+	$lang['bbcode_textsize'] = "Schriftgr&ouml;ssi";
+	$lang['bbcode_extrasmall'] = "Winzig";
+	$lang['bbcode_small'] = "Chli";
+	$lang['bbcode_default'] = "Standard";
+	$lang['bbcode_big'] = "Gross;";
+	$lang['bbcode_extrabig'] = "Riesig";
+	$lang['bbcode_textcolor'] = "Schriftfarb";
+	$lang['bbcode_help_size'] = "Schriftgr&ouml;ssi";
+	$lang['smileys'] = "Smilies:";
+
+	$lang['sendmail_admin_title'] = "Neue G&auml;stebuechitrag vo '{NAME}'";
+	$lang['sendmail_user_title'] = "Ihre Itrag auf {DOMAIN}";
 ?>
