@@ -250,8 +250,8 @@
 				{
 				$sql = "SELECT `code` FROM ".$db['prefix']."captcha LIMIT 1";
 				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 253: ".mysql_error());
-				mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 254: ".mysql_error());
-				$result = mysql_query($sql, $link) or die ("(newentry.php) Error, line 255: ".mysql_error());
+				mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 253: ".mysql_error());
+				$result = mysql_query($sql, $link) or die ("(newentry.php) Error, line 254: ".mysql_error());
 
 				$saved_code = @mysql_fetch_array($result);
 				$captcha_code = $saved_code['code'];
@@ -262,8 +262,8 @@
 				{
 				$sql = "SELECT `sum` FROM ".$db['prefix']."captcha_math LIMIT 1";
 				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 265: ".mysql_error());
-				mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 266: ".mysql_error());
-				$result = mysql_query($sql, $link) or die ("(newentry.php) Error, line 267: ".mysql_error());
+				mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 265: ".mysql_error());
+				$result = mysql_query($sql, $link) or die ("(newentry.php) Error, line 266: ".mysql_error());
 
 				$saved_code = @mysql_fetch_array($result);
 				$captcha_code = $saved_code['sum'];
@@ -464,7 +464,14 @@
 
 		if (isset($_POST['preview']) AND $_POST['preview'] == $lang['preview'] AND $_POST['message'] != "")
 			{
+			$_POST['name'] = cleanstr($_POST['name']);
+			$_POST['city'] = cleanstr($_POST['city']);
 			$_POST['message'] = cleanstr($_POST['message']);
+			$_POST['email'] = cleanstr($_POST['email']);
+			$_POST['icq'] = cleanstr($_POST['icq']);
+			$_POST['aim'] = cleanstr($_POST['aim']);
+			$_POST['msn'] = cleanstr($_POST['msn']);
+			$_POST['hp'] = cleanstr($_POST['hp']);
 			$preview_message = nl2br($_POST['message']);
 			$t1 = chr(10);
 			$t2 = chr(13);
@@ -769,14 +776,14 @@
 			$_POST['message'] = "";
 			}
 
-		$page_newentry_body = template("POST_NAME", $_POST['name'], $page_newentry_body);
-		$page_newentry_body = template("POST_CITY", $_POST['city'], $page_newentry_body);
-		$page_newentry_body = template("POST_EMAIL", $_POST['email'], $page_newentry_body);
-		$page_newentry_body = template("POST_ICQ", $_POST['icq'], $page_newentry_body);
-		$page_newentry_body = template("POST_AIM", $_POST['aim'], $page_newentry_body);
-		$page_newentry_body = template("POST_MSN", $_POST['msn'], $page_newentry_body);
-		$page_newentry_body = template("POST_HP", $_POST['hp'], $page_newentry_body);
-		$page_newentry_body = template("POST_MESSAGE", $_POST['message'], $page_newentry_body);
+		$page_newentry_body = template("POST_NAME", cleanstr($_POST['name']), $page_newentry_body);
+		$page_newentry_body = template("POST_CITY", cleanstr($_POST['city']), $page_newentry_body);
+		$page_newentry_body = template("POST_EMAIL", cleanstr($_POST['email']), $page_newentry_body);
+		$page_newentry_body = template("POST_ICQ", cleanstr($_POST['icq']), $page_newentry_body);
+		$page_newentry_body = template("POST_AIM", cleanstr($_POST['aim']), $page_newentry_body);
+		$page_newentry_body = template("POST_MSN", cleanstr($_POST['msn']), $page_newentry_body);
+		$page_newentry_body = template("POST_HP", cleanstr($_POST['hp']), $page_newentry_body);
+		$page_newentry_body = template("POST_MESSAGE", cleanstr($_POST['message']), $page_newentry_body);
 
 		// fill template with general data
 		$page_newentry_body = template("FORM_ACTION", "newentry.php", $page_newentry_body);
